{Copyright (C) 2006  Benito van der Zander

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
}
unit simpleBrowser_u;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  OleCtrls, SHDocVw_TLB, StdCtrls,shellapi, ExtCtrls, Buttons, ComCtrls,
  ToolWin,rcmdline,inifiles,activex;

type
  TSimpleBrowserForm = class(TForm)
    WebBrowser: TWebBrowser_V1;
    Panel1: TPanel;
    Button1: TButton;
    ToolBar1: TToolBar;
    back: TBitBtn;
    forward: TBitBtn;
    home: TBitBtn;
    ToolButton1: TToolButton;
    status: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure WebBrowserCommandStateChange(Sender: TObject;
      Command: Integer; Enable: WordBool);
    procedure WebBrowserBeforeNavigate(Sender: TObject;
      const URL: WideString; Flags: Integer;
      const TargetFrameName: WideString; var PostData: OleVariant;
      const Headers: WideString; var Cancel: WordBool);
    procedure WebBrowserNavigateComplete(Sender: TObject;
      const URL: WideString);
    procedure backClick(Sender: TObject);
    procedure forwardClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure homeClick(Sender: TObject);
    procedure WebBrowserStatusTextChange(Sender: TObject;
      const Text: WideString);
    procedure FormActivate(Sender: TObject);
    procedure WebBrowserNewWindow(Sender: TObject; const URL: WideString;
      Flags: Integer; const TargetFrameName: WideString;
      var PostData: OleVariant; const Headers: WideString;
      var Processed: WordBool);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
  private
    { Private-Deklarationen }
  public
    { Public-Deklarationen }
    config:TIniFile;
    windowconfigsection: string; //Section in config file to write window pos in
    originalWindow: boolean;
    windowName: widestring; //use for target attribute in links
  end;

var
  SimpleBrowserForm: TSimpleBrowserForm;

  //Globalconfig
  cmdline:TCommandLineReader=nil;
  title: string;
  pageWidth, pageHeight: longint;
  navigation: boolean;
implementation

{$R *.DFM}

procedure TSimpleBrowserForm.FormCreate(Sender: TObject);
begin



  if cmdline=nil then begin
    cmdline:=TCommandLineReader.create;
    cmdline.declareString('site','Zu ffnende Internetseite','http://www.google.de');
    cmdline.declareString('title','Angezeigter Titel','');
    cmdline.declareInt('pageWidth','Breite der angezeigten Seite in Pixeln',WebBrowser.ClientWidth);
    cmdline.declareInt('pageHeight','Hhe der angezeigten Seite in Pixeln',WebBrowser.ClientHeight);
    cmdline.declareFlag('no-navigation','Sollen die Navigationbuttons nicht angezeigt werden',true);
    cmdline.declareString('configFile','Name der Datei, in der die Fenstereinstellungen gespeicehert werden sollen');
    cmdline.declareString('windowSection','Name des Bereichs in dem die Fensterpositionsdaten gespeichert werden sollen.','window');
  //  cmdline.declareFlag('full-border','Soll',true);
    home.click();
    navigation:=cmdline.readFlag('no-navigation');
    title:=cmdline.readString('title');
   // showmessage(cmdline.readString('title'));
    pageWidth:=cmdline.readInt('pageWidth');
    pageHeight:=cmdline.readInt('pageHeight');
    windowconfigsection:=cmdline.readString('windowSection');
    if cmdline.readString('configFile')='' then config:=nil
    else begin
      config:=TIniFile.Create(cmdline.readString('configFile'));
      if not cmdline.existsProperty('pageWidth') then
        width:=config.ReadInteger(windowconfigsection,'width',width);
      if not cmdline.existsProperty('pageHeight') then
        height:=config.ReadInteger(windowconfigsection,'height',height);
    end;
  end;
  Width:=Width-WebBrowser.ClientWidth+pageWidth;
  Height:=Height-WebBrowser.ClientHeight+pageHeight;
  caption:=title;
  ToolBar1.Visible:=navigation;
  if width>screen.width then width:=screen.width;
  if height>screen.height then height:=screen.height;
end;

procedure TSimpleBrowserForm.WebBrowserCommandStateChange(Sender: TObject;
  Command: Integer; Enable: WordBool);
begin
  case command of
    CSC_NAVIGATEFORWARD:forward.enabled:=Enable;
    CSC_NAVIGATEBACK:back.enabled:=Enable;
  end;
end;

procedure TSimpleBrowserForm.WebBrowserBeforeNavigate(Sender: TObject;
  const URL: WideString; Flags: Integer; const TargetFrameName: WideString;
  var PostData: OleVariant; const Headers: WideString;
  var Cancel: WordBool);
begin
  screen.Cursor:=crHourGlass;
end;

procedure TSimpleBrowserForm.WebBrowserNavigateComplete(Sender: TObject;
  const URL: WideString);
begin
  screen.Cursor:=crDefault;
end;

procedure TSimpleBrowserForm.backClick(Sender: TObject);
begin
  WebBrowser.GoBack;
end;

procedure TSimpleBrowserForm.forwardClick(Sender: TObject);
begin
  WebBrowser.GoForward;
end;

procedure TSimpleBrowserForm.Button1Click(Sender: TObject);
begin
  close;
end;

procedure TSimpleBrowserForm.FormDestroy(Sender: TObject);
begin
  if originalWindow then
    cmdline.free;
  if config<>nil then begin
    config.WriteInteger(windowconfigsection,'left',left);
    config.WriteInteger(windowconfigsection,'top',top);
    config.WriteInteger(windowconfigsection,'width',width);
    config.WriteInteger(windowconfigsection,'height',height);
    config.free;
  end;
end;

procedure TSimpleBrowserForm.homeClick(Sender: TObject);
var flags,target,post,header:olevariant;
begin
  WebBrowser.Navigate(cmdline.readString('site'),flags,target,post,header);
end;

procedure TSimpleBrowserForm.WebBrowserStatusTextChange(Sender: TObject;
  const Text: WideString);
begin
  status.Caption:=text;
end;

procedure TSimpleBrowserForm.FormActivate(Sender: TObject);
begin
  if config<>nil then begin
    left:=config.ReadInteger(windowconfigsection,'left',left);
    top:=config.ReadInteger(windowconfigsection,'top',top);
  end;
  if left+width>screen.width then left:=screen.width-width;
  if top+height>screen.height then top:=screen.height-height;
  WebBrowser.SetFocus;
  OnActivate:=nil;
end;

procedure TSimpleBrowserForm.WebBrowserNewWindow(Sender: TObject;
  const URL: WideString; Flags: Integer; const TargetFrameName: WideString;
  var PostData: OleVariant; const Headers: WideString;
  var Processed: WordBool);
var newWindow: TSimpleBrowserForm;
    tempflags,tempURL,tempTarget,tempheaders:OleVariant;
    i:integer;
begin
  newWindow:=nil;
  if (TargetFrameName<>'') and (TargetFrameName[1]<>'_') then
    for i:=0 to Application.ComponentCount-1 do
      if (Application.Components[i] is TSimpleBrowserForm) and
         (TSimpleBrowserForm(Application.Components[i]).windowName=TargetFrameName) then begin
        newwindow:=TSimpleBrowserForm(Application.Components[i]);
        break;
      end;

  if newWindow=nil then 
    newWindow:=TSimpleBrowserForm.Create(Application);
  newWindow.windowName:=TargetFrameName;
  tempURL:=url;
  tempTarget:='';//TargetFrameName;
  tempheaders:=headers;
  tempflags:=flags;
  newWindow.WebBrowser.Navigate(tempurl,tempflags,temptarget,postdata,tempheaders);
  newWindow.show;
  processed:=true;
end;


//Imported procedure
//Author unknown (Sr. Delphi Developer)
procedure WB_ShowFindDialog(AWebbrowser: TWebbrowser_v1);
const
 CGID_WebBrowser: TGUID = '{ED016940-BD5B-11cf-BA4E-00C04FD70816}';
 HTMLID_FIND = 1;
 HTMLID_VIEWSOURCE = 2;
 HTMLID_OPTIONS = 3;
var
 CmdTarget : IOLECommandTarget;
 vaIn, vaOut: OleVariant;
 PtrGUID: PGUID;
begin
 New(PtrGUID);
 PtrGUID^ := CGID_WebBrowser;
 if AWebbrowser.Document <> nil then
   try
     AWebbrowser.Document.QueryInterface(IOleCommandTarget, CmdTarget);
     if CmdTarget <> nil then
       try
         CmdTarget.Exec(PtrGUID, HTMLID_FIND, 0, vaIn, vaOut);
       finally
         CmdTarget._Release;
       end;
   except
     // Nothing
   end;
 Dispose(PtrGUID);
end;

procedure TSimpleBrowserForm.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if (ssCtrl in shift) and (key=ord('F')) then WB_ShowFindDialog(WebBrowser)
end;

end.
